@@ -286,22 +286,22 @@ AVCodecID VideoCodecToCodecID(VideoCodec video_codec) {
 static VideoCodecProfile ProfileIDToVideoCodecProfile(int profile) {
   // Clear out the CONSTRAINED & INTRA flags which are strict subsets of the
   // corresponding profiles with which they're used.
-  profile &= ~AV_PROFILE_H264_CONSTRAINED;
-  profile &= ~AV_PROFILE_H264_INTRA;
+  profile &= ~FF_PROFILE_H264_CONSTRAINED;
+  profile &= ~FF_PROFILE_H264_INTRA;
   switch (profile) {
-    case AV_PROFILE_H264_BASELINE:
+    case FF_PROFILE_H264_BASELINE:
       return H264PROFILE_BASELINE;
-    case AV_PROFILE_H264_MAIN:
+    case FF_PROFILE_H264_MAIN:
       return H264PROFILE_MAIN;
-    case AV_PROFILE_H264_EXTENDED:
+    case FF_PROFILE_H264_EXTENDED:
       return H264PROFILE_EXTENDED;
-    case AV_PROFILE_H264_HIGH:
+    case FF_PROFILE_H264_HIGH:
       return H264PROFILE_HIGH;
-    case AV_PROFILE_H264_HIGH_10:
+    case FF_PROFILE_H264_HIGH_10:
       return H264PROFILE_HIGH10PROFILE;
-    case AV_PROFILE_H264_HIGH_422:
+    case FF_PROFILE_H264_HIGH_422:
       return H264PROFILE_HIGH422PROFILE;
-    case AV_PROFILE_H264_HIGH_444_PREDICTIVE:
+    case FF_PROFILE_H264_HIGH_444_PREDICTIVE:
       return H264PROFILE_HIGH444PREDICTIVEPROFILE;
     default:
       DVLOG(1) << "Unknown profile id: " << profile;
@@ -312,23 +312,23 @@ static VideoCodecProfile ProfileIDToVideoCodecProfile(int profile) {
 static int VideoCodecProfileToProfileID(VideoCodecProfile profile) {
   switch (profile) {
     case H264PROFILE_BASELINE:
-      return AV_PROFILE_H264_BASELINE;
+      return FF_PROFILE_H264_BASELINE;
     case H264PROFILE_MAIN:
-      return AV_PROFILE_H264_MAIN;
+      return FF_PROFILE_H264_MAIN;
     case H264PROFILE_EXTENDED:
-      return AV_PROFILE_H264_EXTENDED;
+      return FF_PROFILE_H264_EXTENDED;
     case H264PROFILE_HIGH:
-      return AV_PROFILE_H264_HIGH;
+      return FF_PROFILE_H264_HIGH;
     case H264PROFILE_HIGH10PROFILE:
-      return AV_PROFILE_H264_HIGH_10;
+      return FF_PROFILE_H264_HIGH_10;
     case H264PROFILE_HIGH422PROFILE:
-      return AV_PROFILE_H264_HIGH_422;
+      return FF_PROFILE_H264_HIGH_422;
     case H264PROFILE_HIGH444PREDICTIVEPROFILE:
-      return AV_PROFILE_H264_HIGH_444_PREDICTIVE;
+      return FF_PROFILE_H264_HIGH_444_PREDICTIVE;
     default:
       DVLOG(1) << "Unknown VideoCodecProfile: " << profile;
   }
-  return AV_PROFILE_UNKNOWN;
+  return FF_PROFILE_UNKNOWN;
 }
 
 SampleFormat AVSampleFormatToSampleFormat(AVSampleFormat sample_format,
@@ -479,7 +479,7 @@ bool AVCodecContextToAudioDecoderConfig(const AVCodecContext* codec_context,
     // TODO(dalecurtis): Just use the profile from the codec context if ffmpeg
     // ever starts supporting xHE-AAC.
     // FFmpeg provides the (defined_profile - 1) for AVCodecContext::profile
-    if (codec_context->profile == AV_PROFILE_UNKNOWN ||
+    if (codec_context->profile == FF_PROFILE_UNKNOWN ||
         codec_context->profile == mp4::AAC::kXHeAAcType - 1) {
       // Errors aren't fatal here, so just drop any MediaLog messages.
       NullMediaLog media_log;
@@ -701,16 +701,16 @@ bool AVStreamToVideoDecoderConfig(const AVStream* stream,
       break;
     case VideoCodec::kVP9:
       switch (codec_context->profile) {
-        case AV_PROFILE_VP9_0:
+        case FF_PROFILE_VP9_0:
           profile = VP9PROFILE_PROFILE0;
           break;
-        case AV_PROFILE_VP9_1:
+        case FF_PROFILE_VP9_1:
           profile = VP9PROFILE_PROFILE1;
           break;
-        case AV_PROFILE_VP9_2:
+        case FF_PROFILE_VP9_2:
           profile = VP9PROFILE_PROFILE2;
           break;
-        case AV_PROFILE_VP9_3:
+        case FF_PROFILE_VP9_3:
           profile = VP9PROFILE_PROFILE3;
           break;
         default:
