@@ -15,6 +15,7 @@
 #include "base/memory/ptr_util.h"
 #include "base/memory/weak_ptr.h"
 #include "base/metrics/histogram_macros.h"
+#include "base/strings/string_number_conversions.h"
 #include "base/task/bind_post_task.h"
 #include "base/task/sequenced_task_runner.h"
 #include "base/time/time.h"
@@ -58,9 +59,9 @@ bool IsSurfaceControlEnabled(const gpu::GpuFeatureInfo& info) {
          gpu::kGpuFeatureStatusEnabled;
 }
 
-std::vector<SupportedVideoDecoderConfig> GetSupportedConfigsInternal(
+std::vector<SupportedVideoDecoderConfig> GenerateSupportedConfigs(
     DeviceInfo* device_info,
-    const bool allow_media_codec_software_decoder) {
+    bool allow_media_codec_sw_decoder) {
   std::vector<SupportedVideoDecoderConfig> supported_configs;
   for (const auto& info : GetDecoderInfoCache()) {
     const auto codec = VideoCodecProfileToVideoCodec(info.profile);
@@ -73,7 +74,7 @@ std::vector<SupportedVideoDecoderConfig> GetSupportedConfigsInternal(
     if ((codec == VideoCodec::kVP8 && device_info->IsVp8DecoderAvailable()) ||
         (codec == VideoCodec::kVP9 && device_info->IsVp9DecoderAvailable()) ||
         (codec == VideoCodec::kAV1 && device_info->IsAv1DecoderAvailable()) ||
-        (codec == VideoCodec::kH264 && IsBuiltInVideoCodec(codec))) {
+        (codec == VideoCodec::kH264 && IsDecoderBuiltInVideoCodec(codec))) {
       // Don't allow OS software decoding for bundled software decoders unless
       // the content is encrypted.
       const bool can_use_builtin_software_decoder =
@@ -81,8 +82,7 @@ std::vector<SupportedVideoDecoderConfig> GetSupportedConfigsInternal(
           info.profile != VP9PROFILE_PROFILE3 &&
           info.secure_codec_capability == SecureCodecCapability::kClear;
       const bool is_os_software_decoder_allowed =
-          !can_use_builtin_software_decoder ||
-          allow_media_codec_software_decoder;
+          !can_use_builtin_software_decoder || allow_media_codec_sw_decoder;
       if (info.is_software_codec && !is_os_software_decoder_allowed) {
         supported_configs.emplace_back(info.profile, info.profile,
                                        info.coded_size_min, info.coded_size_max,
@@ -91,17 +91,8 @@ std::vector<SupportedVideoDecoderConfig> GetSupportedConfigsInternal(
         continue;
       }
 
-      // Require a minimum of 360p even for hardware decoding of VP8+VP9 and
-      // H.264 (if built-in support is available).
-      auto coded_size_min = info.coded_size_min;
-      if (!info.is_software_codec && can_use_builtin_software_decoder &&
-          (codec == VideoCodec::kVP8 || codec == VideoCodec::kVP9 ||
-           codec == VideoCodec::kH264)) {
-        coded_size_min.SetToMax(gfx::Size(360, 360));
-      }
-
       supported_configs.emplace_back(
-          info.profile, info.profile, coded_size_min, info.coded_size_max,
+          info.profile, info.profile, info.coded_size_min, info.coded_size_max,
           kAllowEncrypted,
           /*require_encrypted=*/info.secure_codec_capability ==
               SecureCodecCapability::kEncrypted);
@@ -132,9 +123,7 @@ std::vector<SupportedVideoDecoderConfig> GetSupportedConfigsInternal(
 // Return the name of the decoder that will be used to create MediaCodec.
 void SelectMediaCodec(const VideoDecoderConfig& config,
                       bool requires_secure_codec,
-                      std::string* out_codec_name,
-                      bool* out_is_software_codec) {
-  *out_is_software_codec = false;
+                      std::string* out_codec_name) {
   *out_codec_name = "";
 
   std::string software_decoder;
@@ -180,7 +169,6 @@ void SelectMediaCodec(const VideoDecoderConfig& config,
       continue;
     }
 
-    *out_is_software_codec = false;
     *out_codec_name = info.name;
     return;
   }
@@ -199,13 +187,14 @@ void SelectMediaCodec(const VideoDecoderConfig& config,
         || config.codec() == VideoCodec::kDolbyVision
 #endif  // BUILDFLAG(ENABLE_PLATFORM_DOLBY_VISION)
 #endif  // BUILDFLAG(USE_PROPRIETARY_CODECS)
-        )) {
+        // TODO(b/376720494): Allow this only libvpx doesn't supports HRD.
+        || config.profile() == VP9PROFILE_PROFILE2 ||
+        config.profile() == VP9PROFILE_PROFILE3)) {
     DVLOG(2) << "Can't find proper video decoder from decoder info cache, "
                 "fallback to the default decoder selection path.";
     return;
   }
 
-  *out_is_software_codec = true;
   *out_codec_name = software_decoder;
 }
 
@@ -230,7 +219,7 @@ PendingDecode::~PendingDecode() = default;
 // static
 std::vector<SupportedVideoDecoderConfig>
 MediaCodecVideoDecoder::GetSupportedConfigs() {
-  static const auto configs = GetSupportedConfigsInternal(
+  static const auto configs = GenerateSupportedConfigs(
       DeviceInfo::GetInstance(),
       base::FeatureList::IsEnabled(media::kAllowMediaCodecSoftwareDecoder));
   return configs;
@@ -265,9 +254,9 @@ MediaCodecVideoDecoder::MediaCodecVideoDecoder(
           gpu_preferences.enable_threaded_texture_mailboxes),
       allow_nonsecure_overlays_(
           base::FeatureList::IsEnabled(media::kAllowNonSecureOverlays)),
-      use_block_model_(base::FeatureList::IsEnabled(kMediaCodecBlockModel) &&
-                       device_info_->SdkVersion() >=
-                           base::android::SDK_VERSION_R) {
+      use_block_model_(device_info_->SdkVersion() >=
+                           base::android::SDK_VERSION_V &&
+                       base::FeatureList::IsEnabled(kMediaCodecBlockModel)) {
   DVLOG(2) << __func__;
   surface_chooser_helper_.chooser()->SetClientCallbacks(
       base::BindRepeating(&MediaCodecVideoDecoder::OnSurfaceChosen,
@@ -297,6 +286,7 @@ std::unique_ptr<VideoDecoder> MediaCodecVideoDecoder::Create(
 }
 
 MediaCodecVideoDecoder::~MediaCodecVideoDecoder() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(2) << __func__;
   TRACE_EVENT0("media", "MediaCodecVideoDecoder::~MediaCodecVideoDecoder");
   ReleaseCodec();
@@ -345,6 +335,7 @@ void MediaCodecVideoDecoder::Initialize(const VideoDecoderConfig& config,
                                         InitCB init_cb,
                                         const OutputCB& output_cb,
                                         const WaitingCB& waiting_cb) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DCHECK(output_cb);
   DCHECK(waiting_cb);
 
@@ -362,22 +353,10 @@ void MediaCodecVideoDecoder::Initialize(const VideoDecoderConfig& config,
     return;
   }
 
-  // Tests override the DeviceInfo, so if an override is provided query the
-  // configs as they look under that DeviceInfo. If not, use the default method
-  // which is statically cached for faster Initialize().
-  //
-  // The tests also require the presence of software codecs.
-  const auto configs =
-      device_info_ == DeviceInfo::GetInstance()
-          ? GetSupportedConfigs()
-          : GetSupportedConfigsInternal(
-                device_info_, /*allow_media_codec_software_decoder=*/true);
-
   // If we don't have support support for a given codec, try to initialize
   // anyways -- otherwise we're certain to fail playback.
-  if (!IsVideoDecoderConfigSupported(configs, config) &&
-      IsBuiltInVideoCodec(config.codec())) {
-    DVLOG(1) << "Unsupported configuration.";
+  if (!IsVideoDecoderConfigSupported(GetSupportedConfigsInternal(), config) &&
+      IsDecoderBuiltInVideoCodec(config.codec())) {
     MEDIA_LOG(INFO, media_log_) << "Video configuration is not valid: "
                                 << config.AsHumanReadableString();
     base::BindPostTaskToCurrentDefault(std::move(init_cb))
@@ -395,6 +374,7 @@ void MediaCodecVideoDecoder::Initialize(const VideoDecoderConfig& config,
         .Run(DecoderStatus::Codes::kCantChangeCodec);
     return;
   }
+  const auto old_size = decoder_config_.coded_size();
   decoder_config_ = config;
 
   surface_chooser_helper_.SetVideoRotation(
@@ -435,8 +415,12 @@ void MediaCodecVideoDecoder::Initialize(const VideoDecoderConfig& config,
   // Restrict this behavior to Q, where the behavior changed.
   if (first_init) {
     last_width_ = width;
-  } else if (width > last_width_ * kReallocateThreshold && device_info_ &&
-             device_info_->SdkVersion() > base::android::SDK_VERSION_P) {
+  } else if (CodecNeedsReallocation(width)) {
+    MEDIA_LOG(INFO, media_log_)
+        << "Queuing deferred codec reallocation for resolution change from "
+        << old_size.ToString() << " to "
+        << decoder_config_.coded_size().ToString();
+
     // Reallocate the codec the next time we queue input, once there are no
     // outstanding output buffers.  Note that |deferred_flush_pending_| might
     // already be set, which is fine.  We're just upgrading the flush.
@@ -449,10 +433,16 @@ void MediaCodecVideoDecoder::Initialize(const VideoDecoderConfig& config,
     // race condition in the android framework.
     should_retry_codec_allocation_ = true;
     last_width_ = width;
-  }  // else leave |last_width_| unmodified, since we're re-using the codec.
+  } else {
+    MEDIA_LOG(INFO, media_log_)
+        << "Reusing codec without reallocation for resolution change from "
+        << old_size.ToString() << " to "
+        << decoder_config_.coded_size().ToString();
+  }
 }
 
 void MediaCodecVideoDecoder::SetCdm(CdmContext* cdm_context, InitCB init_cb) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(1) << __func__;
   DCHECK(cdm_context) << "No CDM provided";
   DCHECK(cdm_context->GetMediaCryptoContext());
@@ -475,6 +465,7 @@ void MediaCodecVideoDecoder::OnMediaCryptoReady(
     InitCB init_cb,
     JavaObjectPtr media_crypto,
     bool requires_secure_video_codec) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(1) << __func__
            << ": requires_secure_video_codec = " << requires_secure_video_codec;
 
@@ -515,6 +506,7 @@ void MediaCodecVideoDecoder::OnMediaCryptoReady(
 }
 
 void MediaCodecVideoDecoder::OnCdmContextEvent(CdmContext::Event event) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(2) << __func__;
 
   if (event != CdmContext::Event::kHasAdditionalUsableKey)
@@ -525,6 +517,7 @@ void MediaCodecVideoDecoder::OnCdmContextEvent(CdmContext::Event event) {
 }
 
 void MediaCodecVideoDecoder::StartLazyInit() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(2) << __func__;
   TRACE_EVENT0("media", "MediaCodecVideoDecoder::StartLazyInit");
   lazy_init_pending_ = false;
@@ -561,6 +554,7 @@ void MediaCodecVideoDecoder::StartLazyInit() {
 
 void MediaCodecVideoDecoder::OnVideoFrameFactoryInitialized(
     scoped_refptr<gpu::TextureOwner> texture_owner) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(2) << __func__;
   TRACE_EVENT0("media",
                "MediaCodecVideoDecoder::OnVideoFrameFactoryInitialized");
@@ -596,6 +590,7 @@ void MediaCodecVideoDecoder::OnVideoFrameFactoryInitialized(
 
 void MediaCodecVideoDecoder::OnOverlayInfoChanged(
     const OverlayInfo& overlay_info) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(2) << __func__;
   DCHECK(device_info_->SupportsOverlaySurfaces());
   DCHECK(!enable_threaded_texture_mailboxes_);
@@ -614,6 +609,7 @@ void MediaCodecVideoDecoder::OnOverlayInfoChanged(
 
 void MediaCodecVideoDecoder::OnSurfaceChosen(
     std::unique_ptr<AndroidOverlay> overlay) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(2) << __func__;
   DCHECK(state_ == State::kInitializing ||
          device_info_->IsSetOutputSurfaceSupported());
@@ -638,6 +634,7 @@ void MediaCodecVideoDecoder::OnSurfaceChosen(
 }
 
 void MediaCodecVideoDecoder::OnSurfaceDestroyed(AndroidOverlay* overlay) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(2) << __func__;
   DCHECK_NE(state_, State::kInitializing);
   TRACE_EVENT0("media", "MediaCodecVideoDecoder::OnSurfaceDestroyed");
@@ -679,10 +676,12 @@ void MediaCodecVideoDecoder::OnSurfaceDestroyed(AndroidOverlay* overlay) {
 }
 
 bool MediaCodecVideoDecoder::SurfaceTransitionPending() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   return codec_ && codec_->SurfaceBundle() != target_surface_bundle_;
 }
 
 void MediaCodecVideoDecoder::TransitionToTargetSurface() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(2) << __func__;
   DCHECK(SurfaceTransitionPending());
   DCHECK(device_info_->IsSetOutputSurfaceSupported());
@@ -700,6 +699,7 @@ void MediaCodecVideoDecoder::TransitionToTargetSurface() {
 }
 
 void MediaCodecVideoDecoder::CreateCodec() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DCHECK(!codec_);
   DCHECK(target_surface_bundle_);
   DCHECK_EQ(state_, State::kRunning);
@@ -716,8 +716,8 @@ void MediaCodecVideoDecoder::CreateCodec() {
   config->container_color_space = decoder_config_.color_space_info();
   config->hdr_metadata = decoder_config_.hdr_metadata();
   config->use_block_model = use_block_model_;
-  SelectMediaCodec(decoder_config_, requires_secure_codec_, &config->name,
-                   &is_software_codec_);
+  config->profile = decoder_config_.profile();
+  SelectMediaCodec(decoder_config_, requires_secure_codec_, &config->name);
 
   config->on_buffers_available_cb =
       base::BindPostTaskToCurrentDefault(base::BindRepeating(
@@ -756,6 +756,7 @@ void MediaCodecVideoDecoder::OnCodecConfiguredInternal(
 void MediaCodecVideoDecoder::OnCodecConfigured(
     scoped_refptr<CodecSurfaceBundle> surface_bundle,
     std::unique_ptr<MediaCodecBridge> codec) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DCHECK(!codec_);
   DCHECK_EQ(state_, State::kRunning);
   bool should_retry_codec_allocation = should_retry_codec_allocation_;
@@ -780,16 +781,19 @@ void MediaCodecVideoDecoder::OnCodecConfigured(
     return;
   }
 
-  const auto name = codec->GetName();
-  MEDIA_LOG(INFO, media_log_) << "Created MediaCodec " << name
-                              << ", is_software_codec=" << is_software_codec_;
+  codec_name_ = codec->GetName();
+  MEDIA_LOG(INFO, media_log_)
+      << "Created MediaCodec " << codec_name_
+      << ", is_software_codec=" << codec->IsSoftwareCodec()
+      << ", use_block_model_=" << use_block_model_;
 
   // Since we can't get the coded size w/o rendering the frame, we try to guess
   // in cases where we are unable to render the frame (resolution changes). If
   // we can't guess, there will be a visible rendering glitch.
   std::optional<gfx::Size> coded_size_alignment;
   if (base::FeatureList::IsEnabled(kMediaCodecCodedSizeGuessing)) {
-    coded_size_alignment = MediaCodecUtil::LookupCodedSizeAlignment(name);
+    coded_size_alignment =
+        MediaCodecUtil::LookupCodedSizeAlignment(codec_name_);
     if (coded_size_alignment) {
       MEDIA_LOG(INFO, media_log_) << "Using a coded size alignment of "
                                   << coded_size_alignment->ToString();
@@ -797,7 +801,7 @@ void MediaCodecVideoDecoder::OnCodecConfigured(
       // TODO(crbug.com/40917948): If the known cases work well, we can try
       // guessing generically since we get a glitch either way.
       MEDIA_LOG(WARNING, media_log_)
-          << "Unable to lookup coded size alignment for codec " << name;
+          << "Unable to lookup coded size alignment for codec " << codec_name_;
     }
   }
 
@@ -808,10 +812,9 @@ void MediaCodecVideoDecoder::OnCodecConfigured(
           &OutputBufferReleased,
           base::BindPostTaskToCurrentDefault(base::BindRepeating(
               &MediaCodecVideoDecoder::PumpCodec, weak_factory_.GetWeakPtr()))),
-      base::SequencedTaskRunner::GetCurrentDefault(),
       decoder_config_.coded_size(),
       decoder_config_.color_space_info().ToGfxColorSpace(),
-      coded_size_alignment, use_block_model_);
+      coded_size_alignment);
 
   // If the target surface changed while codec creation was in progress,
   // transition to it immediately.
@@ -829,6 +832,7 @@ void MediaCodecVideoDecoder::OnCodecConfigured(
 
 void MediaCodecVideoDecoder::Decode(scoped_refptr<DecoderBuffer> buffer,
                                     DecodeCB decode_cb) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(3) << __func__ << ": " << buffer->AsHumanReadableString();
   if (state_ == State::kError) {
     std::move(decode_cb).Run(DecoderStatus::Codes::kFailed);
@@ -851,6 +855,7 @@ void MediaCodecVideoDecoder::Decode(scoped_refptr<DecoderBuffer> buffer,
 }
 
 void MediaCodecVideoDecoder::FlushCodec() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(2) << __func__;
 
   // If a deferred flush was pending, then it isn't anymore.
@@ -890,6 +895,7 @@ void MediaCodecVideoDecoder::FlushCodec() {
 }
 
 void MediaCodecVideoDecoder::PumpCodec() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(4) << __func__;
   if (state_ != State::kRunning) {
     return;
@@ -903,6 +909,7 @@ void MediaCodecVideoDecoder::PumpCodec() {
 }
 
 bool MediaCodecVideoDecoder::QueueInput() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(4) << __func__;
   if (!codec_ || waiting_for_key_)
     return false;
@@ -924,10 +931,14 @@ bool MediaCodecVideoDecoder::QueueInput() {
   if (pending_decodes_.empty())
     return false;
 
-  PendingDecode& pending_decode = pending_decodes_.front();
-  if (!use_block_model_ && !pending_decode.buffer->end_of_stream() &&
-      pending_decode.buffer->is_key_frame() &&
-      pending_decode.buffer->size() > max_input_size_) {
+  // TODO(crbug.com/373986013): We take a full ref on the buffer here since
+  // crash data seems to show access violations potentially involving this
+  // buffer.
+  auto pending_buffer = pending_decodes_.front().buffer;
+
+  if (!use_block_model_ && !pending_buffer->end_of_stream() &&
+      pending_buffer->is_key_frame() &&
+      pending_buffer->size() > max_input_size_) {
     // If we we're already using the provided resolution, try to guess something
     // larger based on the actual input size.
     if (decoder_config_.coded_size().width() == last_width_) {
@@ -938,7 +949,7 @@ bool MediaCodecVideoDecoder::QueueInput() {
               ? 2
               : 4;
       const size_t max_pixels =
-          (pending_decode.buffer->size() * compression_ratio * 2) / 3;
+          (pending_buffer->size() * compression_ratio * 2) / 3;
       if (max_pixels > 8294400)  // 4K
         decoder_config_.set_coded_size(gfx::Size(7680, 4320));
       else if (max_pixels > 2088960)  // 1080p
@@ -957,13 +968,55 @@ bool MediaCodecVideoDecoder::QueueInput() {
     }
   }
 
-  auto status = codec_->QueueInputBuffer(*pending_decode.buffer);
+  // See if we can elide the EOS / Flush for a config change. Some platforms
+  // may tear down expensive scaffolding around HDR during a flush.
+  //
+  // Note: Normally we must wait for all buffers to be emitted and rendered
+  // before running the EOS DecodeCB. We're relying on an implementation detail
+  // in DecoderSelector -- that the existing VideoDecoder will be reused.
+  //
+  // If this ever changes, the code below runs the risk of dropping all frames
+  // which haven't been received and rendered from the MediaCodec instance.
+  if (base::FeatureList::IsEnabled(kMediaCodecElideEOS) &&
+      pending_buffer->end_of_stream() && pending_buffer->next_config()) {
+    const auto new_config =
+        absl::get<VideoDecoderConfig>(*pending_buffer->next_config());
+
+    // The underlying MediaCodec must remain the same in order for us to elide
+    // the end of stream flush.
+    const bool can_reuse_codec = [&]() {
+      std::string codec_name;
+      SelectMediaCodec(new_config, requires_secure_codec_, &codec_name);
+      return !codec_name_.empty() && codec_name == codec_name_ &&
+             !CodecNeedsReallocation(new_config.coded_size().width());
+    }();
+
+    if (can_reuse_codec) {
+      MEDIA_LOG(INFO, media_log_)
+          << "Eliding EOS buffer and flush for resolution change from "
+          << decoder_config_.coded_size().ToString() << " to "
+          << new_config.coded_size().ToString();
+      std::move(pending_decodes_.front().decode_cb)
+          .Run(DecoderStatus::Codes::kElidedEndOfStreamForConfigChange);
+      pending_decodes_.pop_front();
+      DCHECK(pending_decodes_.empty());
+      decoder_config_ = new_config;
+
+      // Note: We don't set `last_width_` here since the codec was allocated
+      // with the pre-config change resolution. If `max_input_size_` is
+      // exceeded, the code will detect that `last_width_` doesn't match the
+      // current config and try reallocating at that size.
+      return true;
+    }
+  }
+
+  auto status = codec_->QueueInputBuffer(*pending_buffer);
   DVLOG((status.code() == CodecWrapper::QueueStatus::Codes::kTryAgainLater ||
                  status.is_ok()
              ? 3
              : 2))
-      << "QueueInput(" << pending_decode.buffer->AsHumanReadableString()
-      << ") status=" << MediaSerialize(status);
+      << "QueueInput(" << pending_buffer->AsHumanReadableString()
+      << ") status=" << status.message();
 
   switch (status.code()) {
     case CodecWrapper::QueueStatus::Codes::kOk:
@@ -982,20 +1035,22 @@ bool MediaCodecVideoDecoder::QueueInput() {
       return false;
   }
 
-  if (pending_decode.buffer->end_of_stream()) {
+  if (pending_buffer->end_of_stream()) {
     // The VideoDecoder interface requires that the EOS DecodeCB is called after
     // all decodes before it are delivered, so we have to save it and call it
     // when the EOS is dequeued.
     DCHECK(!eos_decode_cb_);
-    eos_decode_cb_ = std::move(pending_decode.decode_cb);
+    eos_decode_cb_ = std::move(pending_decodes_.front().decode_cb);
   } else {
-    std::move(pending_decode.decode_cb).Run(DecoderStatus::Codes::kOk);
+    std::move(pending_decodes_.front().decode_cb)
+        .Run(DecoderStatus::Codes::kOk);
   }
   pending_decodes_.pop_front();
   return true;
 }
 
 bool MediaCodecVideoDecoder::DequeueOutput() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(4) << __func__;
   if (!codec_ || codec_->IsDrained() || waiting_for_key_)
     return false;
@@ -1032,7 +1087,7 @@ bool MediaCodecVideoDecoder::DequeueOutput() {
   }
   DVLOG(3) << "DequeueOutputBuffer(): pts="
            << (eos ? "EOS"
-                   : std::to_string(presentation_time.InMilliseconds()));
+                   : base::NumberToString(presentation_time.InMilliseconds()));
 
   if (eos) {
     if (eos_decode_cb_) {
@@ -1085,6 +1140,7 @@ bool MediaCodecVideoDecoder::DequeueOutput() {
 }
 
 void MediaCodecVideoDecoder::RunEosDecodeCb(int reset_generation) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   // Both of the following conditions are necessary because:
   //  * In an error state, the reset generations will match but |eos_decode_cb_|
   //    will be aborted.
@@ -1099,6 +1155,7 @@ void MediaCodecVideoDecoder::ForwardVideoFrame(
     std::unique_ptr<ScopedAsyncTrace> async_trace,
     base::TimeTicks started_at,
     scoped_refptr<VideoFrame> frame) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(3) << __func__ << " : "
            << (frame ? frame->AsHumanReadableString() : "null");
 
@@ -1137,6 +1194,7 @@ void MediaCodecVideoDecoder::ForwardVideoFrame(
 // 1) no VideoFrames from before the Reset() will be output, and
 // 2) no DecodeCBs (including EOS) from before the Reset() will be run.
 void MediaCodecVideoDecoder::Reset(base::OnceClosure closure) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(2) << __func__;
   DCHECK(!reset_cb_);
   reset_generation_++;
@@ -1146,6 +1204,7 @@ void MediaCodecVideoDecoder::Reset(base::OnceClosure closure) {
 }
 
 void MediaCodecVideoDecoder::StartDrainingCodec(DrainType drain_type) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(2) << __func__;
   TRACE_EVENT0("media", "MediaCodecVideoDecoder::StartDrainingCodec");
   DCHECK(pending_decodes_.empty());
@@ -1172,6 +1231,7 @@ void MediaCodecVideoDecoder::StartDrainingCodec(DrainType drain_type) {
 }
 
 void MediaCodecVideoDecoder::OnCodecDrained() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DVLOG(2) << __func__;
   TRACE_EVENT0("media", "MediaCodecVideoDecoder::OnCodecDrained");
   DrainType drain_type = *drain_type_;
@@ -1196,6 +1256,7 @@ void MediaCodecVideoDecoder::OnCodecDrained() {
 
 void MediaCodecVideoDecoder::EnterTerminalState(State state,
                                                 DecoderStatus reason) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   // Any nested error inside `reason` not displayed as the error is propagated
   // to the caller.
   DVLOG(2) << __func__ << " " << static_cast<int>(state) << " "
@@ -1221,10 +1282,12 @@ void MediaCodecVideoDecoder::EnterTerminalState(State state,
 }
 
 bool MediaCodecVideoDecoder::InTerminalState() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   return state_ == State::kSurfaceDestroyed || state_ == State::kError;
 }
 
 void MediaCodecVideoDecoder::CancelPendingDecodes(DecoderStatus status) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   for (auto& pending_decode : pending_decodes_)
     std::move(pending_decode.decode_cb).Run(status);
   pending_decodes_.clear();
@@ -1233,6 +1296,7 @@ void MediaCodecVideoDecoder::CancelPendingDecodes(DecoderStatus status) {
 }
 
 void MediaCodecVideoDecoder::ReleaseCodec() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   if (!codec_)
     return;
   auto pair = codec_->TakeCodecSurfacePair();
@@ -1246,6 +1310,7 @@ void MediaCodecVideoDecoder::ReleaseCodec() {
 }
 
 AndroidOverlayFactoryCB MediaCodecVideoDecoder::CreateOverlayFactoryCb() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   if (!overlay_factory_cb_ || !overlay_info_.HasValidRoutingToken())
     return AndroidOverlayFactoryCB();
 
@@ -1261,6 +1326,7 @@ bool MediaCodecVideoDecoder::NeedsBitstreamConversion() const {
 }
 
 bool MediaCodecVideoDecoder::CanReadWithoutStalling() const {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   // We should always be able to get at least two outputs, one in the front
   // buffer slot and one in the back buffer slot unless we're waiting for
   // rendering to happen.
@@ -1278,6 +1344,7 @@ int MediaCodecVideoDecoder::GetMaxDecodeRequests() const {
 
 PromotionHintAggregator::NotifyPromotionHintCB
 MediaCodecVideoDecoder::CreatePromotionHintCB() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   // Right now, we don't request promotion hints.  This is only used by SOP.
   // While we could simplify it a bit, this is the general form that we'll use
   // when handling promotion hints.
@@ -1306,19 +1373,43 @@ MediaCodecVideoDecoder::CreatePromotionHintCB() {
 }
 
 bool MediaCodecVideoDecoder::IsUsingOverlay() const {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   return codec_ && codec_->SurfaceBundle() &&
          codec_->SurfaceBundle()->overlay();
 }
 
 void MediaCodecVideoDecoder::NotifyPromotionHint(
     PromotionHintAggregator::Hint hint) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   surface_chooser_helper_.NotifyPromotionHintAndUpdateChooser(hint,
                                                               IsUsingOverlay());
 }
 
 void MediaCodecVideoDecoder::CacheFrameInformation() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   cached_frame_information_ =
       surface_chooser_helper_.ComputeFrameInformation(IsUsingOverlay());
 }
 
+bool MediaCodecVideoDecoder::CodecNeedsReallocation(int new_width) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
+  return !use_block_model_ && new_width > last_width_ * kReallocateThreshold &&
+         device_info_ &&
+         device_info_->SdkVersion() > base::android::SDK_VERSION_P;
+}
+
+std::vector<SupportedVideoDecoderConfig>
+MediaCodecVideoDecoder::GetSupportedConfigsInternal() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
+  // Tests override the DeviceInfo, so if an override is provided query the
+  // configs as they look under that DeviceInfo.
+  if (device_info_ != DeviceInfo::GetInstance()) {
+    return GenerateSupportedConfigs(device_info_,
+                                    /*allow_media_codec_sw_decoder=*/true);
+  }
+
+  // Use the default cached results if minimum resolutions should be enforced.
+  return GetSupportedConfigs();
+}
+
 }  // namespace media
