@@ -1,7 +1,5 @@
 // Copyright (C) 2024 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
-// Qt-Security score:significant reason:default
-
 #include "qquickwebengineprofileprototype_p.h"
 #include "qquickwebengineprofileprototype_p_p.h"
 #include "profile_adapter.h"
@@ -163,6 +161,9 @@ void QQuickWebEngineProfilePrototype::setHttpCacheType(
             Cookies marked persistent are saved to and restored from disk, whereas session cookies
             are only stored to disk for crash recovery.
             This is the default value for non off-the-record profile with storageName.
+    \value  WebEngineProfile.OnlyPersistentCookies
+            Cookies marked persistent are saved to and restored from disk, whereas session cookies
+            are never stored to the disk, even for crash recovery.
     \value  WebEngineProfile.ForcePersistentCookies
             Both session and persistent cookies are saved to and restored from disk.
 */
@@ -330,12 +331,8 @@ void QQuickWebEngineProfilePrototype::componentComplete()
                     d_ptr->m_persistentCookiesPolicy),
             d_ptr->m_httpCacheMaxSize,
             QtWebEngineCore::ProfileAdapter::PersistentPermissionsPolicy(
-                    d_ptr->m_persistentPermissionsPolicy)
-#if QT_CONFIG(ssl)
-                    ,
-            additionalCertificates
-#endif
-    );
+                    d_ptr->m_persistentPermissionsPolicy),
+            additionalCertificates);
 
     d_ptr->profile.reset(new QQuickWebEngineProfile(
             new QQuickWebEngineProfilePrivate(profileAdapter), this->parent()));
