@@ -537,6 +537,35 @@ bool QQuickWebEngineSettings::touchEventsApiEnabled() const
     return d_ptr->testAttribute(QWebEngineSettings::TouchEventsApiEnabled);
 }
 
+/*!
+    \qmlproperty bool WebEngineSettings::backForwardCacheEnabled
+    \since QtWebEngine 6.10
+
+    Enables support for back/forward cache (or bfcache) to speed up back and
+    forward navigation.
+
+    Disabled by default.
+*/
+bool QQuickWebEngineSettings::backForwardCacheEnabled() const
+{
+    return d_ptr->testAttribute(QWebEngineSettings::BackForwardCacheEnabled);
+}
+
+/*!
+    \qmlproperty bool WebEngineSettings::trimAccessibilityIdentifiers
+    \since QtWebEngine 6.11
+
+    Forces the HTML 'id' attribute to be used as the automation ID (QAccessible::Identifier)
+    without modification. When disabled, Qt will instead prepend the entire object hierarchy
+    to the identifier.
+
+    Disabled by default.
+*/
+bool QQuickWebEngineSettings::trimAccessibilityIdentifiers() const
+{
+    return d_ptr->testAttribute(QWebEngineSettings::TrimAccessibilityIdentifiers);
+}
+
 /*!
     \qmlproperty string WebEngineSettings::defaultTextEncoding
     \since QtWebEngine 1.2
@@ -929,6 +958,22 @@ void QQuickWebEngineSettings::setTouchEventsApiEnabled(bool on)
         Q_EMIT touchEventsApiEnabledChanged();
 }
 
+void QQuickWebEngineSettings::setBackForwardCacheEnabled(bool on)
+{
+    bool wasOn = d_ptr->testAttribute(QWebEngineSettings::BackForwardCacheEnabled);
+    d_ptr->setAttribute(QWebEngineSettings::BackForwardCacheEnabled, on);
+    if (wasOn != on)
+        Q_EMIT backForwardCacheEnabledChanged();
+}
+
+void QQuickWebEngineSettings::setTrimAccessibilityIdentifiers(bool on)
+{
+    bool wasOn = d_ptr->testAttribute(QWebEngineSettings::TrimAccessibilityIdentifiers);
+    d_ptr->setAttribute(QWebEngineSettings::TrimAccessibilityIdentifiers, on);
+    if (wasOn != on)
+        Q_EMIT trimAccessibilityIdentifiersChanged();
+}
+
 QT_END_NAMESPACE
 
 #include "moc_qquickwebenginesettings_p.cpp"
