@@ -1,18 +1,15 @@
 // Copyright (C) 2016 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
-#include <QtTest/QtTest>
-#include <QTemporaryDir>
-#include <QtWebEngineCore/qwebengineprofilebuilder.h>
-
-#if QT_CONFIG(ssl)
 #include <httpsserver.h>
 #include <util.h>
+#include <QtTest/QtTest>
 #include <QtTest/private/qtesthelpers_p.h>
+#include <QTemporaryDir>
+#include <QtWebEngineCore/qwebengineprofilebuilder.h>
 #include <QtWebEngineCore/qwebenginecertificateerror.h>
 #include <QtWebEngineCore/qwebengineclientcertificatestore.h>
 #include <QtWebEngineCore/qwebenginesettings.h>
-#endif
 
 class tst_QWebEngineProfileBuilder : public QObject
 {
@@ -30,9 +27,7 @@ private Q_SLOTS:
     void httpCacheSize();
     void persistentPermissionsPolicy_data();
     void persistentPermissionsPolicy();
-#if QT_CONFIG(ssl)
     void additionalTrustedCertificates();
-#endif
     void useSameDataPathForProfiles();
 };
 
@@ -169,10 +164,16 @@ void tst_QWebEngineProfileBuilder::persistentCookiesPolicy_data()
             << QWebEngineProfile::NoPersistentCookies << true;
     QTest::newRow("allowPersistentCookiesOffTheRecord")
             << QWebEngineProfile::AllowPersistentCookies << true;
+    QTest::newRow("onlyPersistentCookiesOffTheRecord")
+            << QWebEngineProfile::OnlyPersistentCookies << true;
+    QTest::newRow("forcePersistentCookiesOffTheRecord")
+            << QWebEngineProfile::ForcePersistentCookies << true;
     QTest::newRow("forcePersistentCookiesDiskBasedProfile")
             << QWebEngineProfile::ForcePersistentCookies << false;
     QTest::newRow("allowPersistentCookiesDiskBasedProfile")
             << QWebEngineProfile::AllowPersistentCookies << false;
+    QTest::newRow("onlyPersistentCookiesDiskBasedProfile")
+            << QWebEngineProfile::OnlyPersistentCookies << false;
     QTest::newRow("noPersistentCookiesDiskBasedProfile")
             << QWebEngineProfile::NoPersistentCookies << false;
 }
@@ -287,7 +288,6 @@ void tst_QWebEngineProfileBuilder::persistentPermissionsPolicy()
     QCOMPARE(profile->persistentStoragePath(), storagePath);
 }
 
-#if QT_CONFIG(ssl)
 void tst_QWebEngineProfileBuilder::additionalTrustedCertificates()
 {
     if (QTestPrivate::isSecureTransportBlockingTest()) {
@@ -378,7 +378,6 @@ void tst_QWebEngineProfileBuilder::additionalTrustedCertificates()
 
     QVERIFY(server.stop());
 }
-#endif // QT_CONFIG(ssl)
 
 void tst_QWebEngineProfileBuilder::useSameDataPathForProfiles()
 {
